@@ -64,20 +64,27 @@ def waitForResponse(header: str, footer: str):
             break
 
 
+def executeCommand(pump, command, waitForPump=False):
+    #pump.checkValidity()
+    return send_command(pump.asciiAddress, command, waitForPump)
+
+
 def send_command(pumpAddress: str, message: str, waitForPump=False):
     commandHeader = '/' + pumpAddress
     commandFooter = '\r\n'
+
     command = commandHeader + message + commandFooter
+    print("Command: " + command)
     encoded_command = str.encode(command)
     ser.write(encoded_command)
     respondbytes2 = ser.readline()  # Read from Serial Port
     print(respondbytes2)
-    decoded_temp2 = respondbytes2.decode()
+    response = respondbytes2.decode()
     print('Response :')
-    print(decoded_temp2)
+    print(response)
+
     if waitForPump:
         waitForResponse(commandHeader, commandFooter)
 
-
-
+    return response
 
