@@ -1,4 +1,4 @@
-from util import *
+#from .util import *
 from .commandPSD4 import *
 from .commandPSD6 import *
 from .commandPSD4SmoothFlow import *
